#
# spec file for package mergiraf
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mergiraf
Version:        0.8.1
Release:        1.1
Summary:        A syntax-aware git merge driver
License:        GPL-3.0-or-later
Group:          Development/Tools/Version Control
URL:            https://mergiraf.org/
#Git-Clone:     https://codeberg.org/mergiraf/mergiraf.git
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  git-core
ExclusiveArch:  %{rust_tier1_arches}

%description
Mergiraf can solve a wide range of Git merge conflicts.
That's because it's aware of the trees in your files!

Thanks to its understanding of your language, it can often
reconcile the needs of both sides.

%prep
%autosetup -a 1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/mergiraf
%{_bindir}/mgf_dev

%changelog
* Sat May 17 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.1
  * Maintenance release to update out of a yanked dependency.
- Update to version 0.8.0
  General improvements
  * feat: Specify different separators for each children group of
    a commutative parent.
  * fix: Avoid displaying spurious conflicts.
  * fix: Check that the merged text is syntactically valid and
    consistent with the merged tree.
  * fix: Handling of duplicate signatures in base revision.
  * fix: Don't match nodes of different types.
  * fix: Writing changeset to debug dir.
  Language-specific improvements
  * C/C++: Restrict commutativity of initializer_list.
  * C/C++: even more C++ file extensions.
  * C#: Restrict commutativity.
  * YAML: Fix handling of quoted strings.
- Update to version 0.7.0
  New languages
  * Java Properties (.properties).
  UX improvements
  * file formats can be selected manually using the new
  - -language option.
  * zdiff3-style conflicts are detected and warned against, as
    Mergiraf doesn't support solving those.
  * using mergiraf solve together with jj gives a helpful error
    message.
  * the --keep option of mergiraf solve was renamed to --stdout.
  Bug fixes
  * Incorrect resolution of delete-delete conflict.
  * Spurious indentation changes on untouched nodes.
  * Missing file extensions for C++.
  * Unidentified conflict between --keep-backup and --stdout.
  * The --debug option was advertised in commands where it doesn't
    have any effect.
  * Java: Missing commutativity for 'throws' declarations.
  * Java: Missing commutativity in interfaces.
  * Python: Missing commutativity for "import from" statements.
  Performance
  * Many optimizations.
* Sun Mar  2 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.0:
  New language
  * SystemVerilog (*.sv, *.svh).
  * Nix (*.nix).
  New features
  * feat(LangProfile::detect_from_filename): handle extension
    comparison more correctly.
  * feat(MergedTree::line_based_local_fallback_for_revnode): handle
    the case of isomorphic left and right sides.
  * feat(line_based_merge_with_duplicate_signature_detection): if
    the line-merge has conflicts, reconstruct and check each
    revision.
  * feat: Add command to compare files by tree isomorphism.
  Fixes
  * fix(cli): add . to extensions in languages output.
  * fix(cli): add actual docs to --conflict-marker-size option.
  * fix(MergedTree/count_conflicts): respect conflict marker size.
  * fix(highlight_duplicate_signatures): don't remove separators
    if no conflict was built.
  * fix(TreeBuilder): resolve not-really-conflicts (left and right
    agree).
  Performance improvements
  * perf: use rustc-hash in more places.
* Sat Feb  8 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.1:
  Bugfix release
  * The --compact option works again, without needing to supply
    "--compact=true".
* Thu Feb  6 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.0:
  New languages
  * PHP
  * Solidity
  * TSX
  * Lua
  * Kotlin
  * Devicetree
  * Ruby
  Improvements
  * The histogram diff algorithm is used for line-based merges.
  * The mgf_dev parse command correctly displays nodes that have
    a signature and are commutative at the same time.
  * Don't add a newline at the end of merged / to-be-merged files.
  * Also parse correctly conflicts with non-newline-terminated
    sides.
  * The --keep-output option was added to the mergiraf solve to
    control the creation of .orig files.
  * The conflict size marker size can be controlled with option -l
  * The commutativity of various syntactic elements was restricted
    to avoid bad merges.
  * A --timeout option is available in mergiraf merge, to fall
    back on line-based merging if structured merging takes too
    long.
  * A panic when failing to commutatively merge a root node was
    fixed.
  Compatibility
  * Support for the MERGIRAF_DISABLE environment variable was
    removed, use mergiraf=0 instead.
  Performance
  * Many improvements reducing memory allocations.
* Sun Dec  8 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0:
  New languages
  * Python
  * TOML
  * Scala
  * Typescript
  Performance
  * Many performance improvements.
  Bug fixes
  * The solve command preserves revision names in conflicts.
  * Don't swallow trailing whitespace of merged nodes.
  * Make helpers runnable from any directory.
  New features
  * Replace MERGIRAF_DISABLE=1 by mergiraf=0
  * Support for restricting commutativity.
* Wed Nov 13 2024 mardnh@gmx.de
- Update to version 0.3.1:
  * Updated tree-sitter-xml to 0.7.0
* Tue Nov 12 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.0
  * New language: Dart (*.dart).
  * .cc files are correctly detected as C++.
  * Documentation improvements.
  * Fixes to the integration test suite when GPG signing is enabled
* Sun Nov 10 2024 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.2.0
